@@ -4,8 +4,8 @@
 const int ITER = 2;
 class SleepThr: public QpThread {
     public:
-	~SleepThr() {Join();}
-	void Main() {
+	virtual ~SleepThr() {Join();}
+	virtual void Main() {
 		for (int i = 0; i < ITER; i++) {
 			cout << i << "    " << ThreadSeq() << " - Sleep ";
 			cout.flush();
